<?php
/*
Plugin Name: WP socialshareprivacy
Plugin URI: http://wordpress.org/extend/plugins/wp-socialshareprivacy/
Version: 0.3
Description: Adds 2-click-privacy social buttons (Facebook, Twitter, G+). See <a href="http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html">article on heise online</a>.
Author: Philipp Bochskandl
Text Domain: wp-socialshareprivacy

    Copyright 2011  Philipp Bochskandl

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
    
*/


function addContent($content = '') {
	if ( !is_singular() ) {
		return $content;
	}
	
	$base_url = plugins_url('/wp-socialshareprivacy/');
	$options = array(
		info_link      => 'http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html',
		txt_help       => 'Wenn Sie diese Felder durch einen Klick aktivieren, werden Informationen an Facebook, Twitter oder Google in die USA &uuml;bertragen und unter Umst&auml;nden auch dort gespeichert. N&auml;heres erfahren Sie durch einen Klick auf das <em>i</em>.',
		settings_perma => 'Dauerhaft aktivieren und Daten&uuml;ber&shy;tragung zustimmen:',
		cookie_path    => '/',
		cookie_expire  => 365,
		css_path       => $base_url . 'socialshareprivacy.css',
		services       => array(
			facebook => array(
				status          => 'on',
				app_id          => 'FIXME',
				dummy_img       => $base_url . 'images/dummy_facebook.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Facebook senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_fb_off      => 'nicht mit Facebook verbunden',
				txt_fb_on       => 'mit Facebook verbunden',
				display_name    => 'Facebook',
				referrer_track  => '',
				language        => 'de_DE'
			),
			twitter  => array(
				status          => 'on',
				dummy_img       => $base_url . 'images/dummy_twitter.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Twitter senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_twitter_off => 'nicht mit Twitter verbunden',
				txt_twitter_on  => 'mit Twitter verbunden',
				display_name    => 'Twitter',
				referrer_track  => '',
				tweet_text      => 'getTweetText'
			),
			gplus    => array(
				status          => 'on',
				dummy_img       => $base_url . 'images/dummy_gplus.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Google+ senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_twitter_off => 'nicht mit Google+ verbunden',
				txt_twitter_on  => 'mit Google+ verbunden',
				display_name    => 'Google+',
				referrer_track  => '',
				language        => 'de'
			)
		)
	);
	if ( get_option('wpssp_options' ) ) {
		foreach (get_option('wpssp_options') as $key => $value) {
			
			if ( preg_match('/^services_(facebook|twitter|gplus)_(.*)$/', $key, $matches ) ) {
				$options[services][$matches[1]][$matches[2]] = $value;
			}
			else {
				$options[$key] = $value;
			}
		}
	}
	$content .= '<div id="socialshareprivacy"></div>';
	$content .= "
		<script>
		(function(\$){
			var options = " . json_encode($options) . ";
			options.cookie_domain = document.location.host;
			$(document).ready(function(){
				\$('#socialshareprivacy').socialSharePrivacy(options);
			});
		})(jQuery);
		</script>
	";
	return $content;
}

function enqueue_styles() {
	wp_enqueue_style('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/socialshareprivacy.css');
}
 
function enqueue_scripts() {
	wp_enqueue_script('jquery');
	wp_enqueue_script('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/jquery.socialshareprivacy.min.js');
}

function create_admin_menu() {
	add_options_page(
		'WP socialshareprivacy Settings',
		'WP socialshareprivacy',
		'administrator',
		'wp-socialshareprivacy',
		'wpssp_settings_page',
		plugins_url('/wp-socialshareprivacy/screenshot-4.jpg')
	);
	add_action( 'admin_init', 'register_settings' );
}

function register_settings() {
	register_setting( 'wpssp-settings-group', 'wpssp_options' );
	
	//  $id, $title, $callback, $page 
	add_settings_section('wpssp_g', 'Allgemeines', 'admin_general_description', 'wpssp');
	add_settings_section('wpssp_fb', 'Facebook', 'admin_facebook_description', 'wpssp');
	add_settings_section('wpssp_tw', 'Twitter', 'admin_twitter_description', 'wpssp');
	add_settings_section('wpssp_gp', 'Google+', 'admin_gplus_description', 'wpssp');
	
	// $id, $title, $callback, $page, $section, $args
	add_settings_field('wpssp_infolink', 'Info-Link', 'opt_disabled', 'wpssp', 'wpssp_g');
	add_settings_field('wpssp_txt_help', 'Hilfetext', 'opt_disabled', 'wpssp', 'wpssp_g');
	add_settings_field('wpssp_settings_perma', 'Info-Text', 'opt_disabled', 'wpssp', 'wpssp_g');
	add_settings_field('wpssp_cookie_domain', 'Cookie domain', 'opt_cookie_domain', 'wpssp', 'wpssp_g');
	add_settings_field('wpssp_cookie_path', 'Cookie path', 'opt_disabled', 'wpssp', 'wpssp_g');
	add_settings_field('wpssp_expire', 'Cookie expire time', 'opt_disabled', 'wpssp', 'wpssp_g');
	
	add_settings_field('wssp_services_facebook_app_id', 'App Id', 'opt_services_facebook_app_id', 'wpssp', 'wpssp_fb');
}

function opt_disabled() {
	?><input style="background: #eee;" type="text" disabled="disabled" /><?php
}

function opt_cookie_domain($foo) {
	$options = get_option('wpssp_options');
	?><input name="wpssp_options[cookie_domain]" type="text" value="<?php echo $options['cookie_domain'] ?>" /><?php
}

function opt_services_facebook_app_id() {
	$options = get_option('wpssp_options');
	?><input name="wpssp_options[services_facebook_app_id]" type="text" value="<?php echo $options['services_facebook_app_id'] ?>" /><?php
}

function admin_general_description() {
	?><p><b>Dies ist eine Vorab-Testversion. In Kürze wird eine vollständig funktionsfähige Version veröffentlicht.</b></p><?php
}

function admin_facebook_description() {
	?>
	<h4 id="fb_app-id">Hinweis zur Facebook App-ID</h4>
	<p>
	Für den &bdquo;Empfehlen&ldquo;-Button von Facebook benötigt man eine Facebook App-ID. Diese kann man sich mit seinem verifizierten Facebook-Konto auf den Developer-Seiten erzeugen.
	</p>
	<ol id="fb_app_id_step_by_step">
	<li>Einloggen bei Facebook</li>
	<li>Konto verifizieren mittels Handy-Nummer (oder Kreditkartendaten)<br />
	<a href="https://www.facebook.com/settings?tab=mobile">https://www.facebook.com/settings?tab=mobile</a>
	Option Handy-Nr.:<br />
	Handy-Nr. eintragen und anschließend per SMS empfangenen Bestätigungscode in das Feld auf der rechten Seite eintragen.
	</li>
	<li>Entwickler-Seite aufrufen<br />
	<a href="http://developers.facebook.com/docs/reference/plugins/like/">http://developers.facebook.com/docs/reference/plugins/like/</a><br />
	Dort in der Box unter "Step 1" auf "Get Code" klicken und die App-ID aus dem angezeigten Code-Teil entnehmen.
	                </li> 
	</ol>
	<?php
}

function admin_twitter_description() {
	echo '<p>(options coming soon)</p>';
}

function admin_gplus_description() {
	echo '<p>(options coming soon)</p>';
}

function wpssp_settings_page() {
	?>
	<div class="wrap">
	<h2>WP socialshareprivacy</h2>
		<form action="options.php" method="post">
		<?php settings_fields('wpssp-settings-group'); ?>
		<?php do_settings_sections('wpssp'); ?>
		
	    <p class="submit">
	    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
	    </p>
		</form>
	</div>
	
	<?php
}

function main() {
	
	// Frontend
	wp_enqueue_script("jquery");
	add_filter('the_content', 'addContent');
	add_action( 'wp_print_scripts', 'enqueue_scripts' );
	add_action( 'wp_print_styles', 'enqueue_styles' );
	
	// Backend
	if ( is_admin() ) {
		add_action('admin_menu', 'create_admin_menu');
	}
}

main();

?>